@@ -1462,7 +1462,7 @@ class DatabaseManager:
         self.con = None
         self.cur = None
 
-    def execute_single_statement(self, sql:str, args=False):
+    def execute_single_statement(self, sql:str, args=False,isTimeoutRetry=False):
         '''
             Executes a single SQL query on the database.
 
@@ -1510,6 +1510,17 @@ class DatabaseManager:
             _log(f"{_traceback.format_exc()}","error")
             _log(f"SQL: {sql}","error")
 
+        except mysql.connector.errors.InterfaceError:
+            if isTimeoutRetry is True:
+                _log(f"{_traceback.format_exc()}","error")
+                _log(f"SQL: {sql}","error")
+            if isTimeoutRetry is False:
+                # _log(f"CONNECTION TIMED OUT")
+                self.cur = None
+                self.con = None
+                self.connect()
+                return self.execute_single_statement(sql,args,True)
+
         except mysql.connector.errors.DatabaseError:
             # print(f"ERROR: {err}", PRESET="FATAL_ERROR_INVERT")
             _log(f"{_traceback.format_exc()}","error")
@@ -1658,16 +1669,17 @@ class DatabaseManager:
 
         with open(filePath, 'r', encoding='utf-8') as file:
             sql = file.read()
-            # statements = 
+            print(f"filePath:{filePath}")
             statements = [str(x) for x in _csu.sql.get_statements(sql)]
             # sql = _csu.strip_sql_comments(sql)
+            # _re.sub(r";")
             # sql = sql.replace(";", ";STATEMENT_END")
             # statements = sql.split('STATEMENT_END')
 
         # self.run("SET foreign_key_checks=0;")
         # "SOURCE /backups/mydump.sql;" -- restore your backup within THIS session
         # statements = getSQLStatementsFromFile(filePath)
-        # print(f"statements: {statements}")
+        print(f"total statements: {len(statements)}")
         disable_foreign_key_restraints = True
         if 'DISABLE_KEY_RESTRAINTS' in kwargs:
             if kwargs['DISABLE_KEY_RESTRAINTS'] is False:
