@@ -333,7 +333,7 @@ def _group_insert_data(data,group_size=500,semicolon=True):
 
         insert_group = []
         for dd in raw_group:
-            dd = _csu.unicode_to_html(dd,semicolon)
+            dd = _csu.unicode_to_html(dd,semicolon=semicolon)
             insert_group.append(dd)
         inserts.append(insert_group)
         # sql = c.string.sql.insert_sql(insert_group,"cities","idealech_Equari_Meta")
@@ -417,7 +417,7 @@ def insert_sql(data,table_name,schema_name=None,**kwargs):
                 # @Mstep [LOOP] iterate the sliced data groups
                 for ins in inserts:
                     # @Mstep [] generate the sql for the group
-                    group_sql = insert_sql(ins)
+                    group_sql = insert_sql(ins,table_name,schema_name,**kwargs)
                     # @Mstep [IF] if the sql qas successfully generated.
                     if isinstance(group_sql,(str)):
                         # @Mstep [] concatenate the group sql to the preceding sql.
